==> smartgwtee-eval-6.0p.zip: smartgwtee-6.0p/samples/showcase/src/com/smartgwt/sample/showcase/client/dataintegration/java/jpa/JPASample.java <==
/*
 * Isomorphic SmartGWT web presentation layer
 * Copyright 2000 and beyond Isomorphic Software, Inc.
 *
 * OWNERSHIP NOTICE
 * Isomorphic Software owns and reserves all rights not expressly granted in this source code,
 * including all intellectual property rights to the structure, sequence, and format of this code
 * and to all designs, interfaces, algorithms, schema, protocols, and inventions expressed herein.
 *
 *  If you have any questions, please email <sourcecode@isomorphic.com>.
 *
 *  This entire comment must accompany any portion of Isomorphic Software source code that is
 *  copied or moved from this file.
 */
package com.smartgwt.sample.showcase.client.dataintegration.java.jpa;

import com.smartgwt.client.data.DataSource;
import com.smartgwt.client.types.ListGridEditEvent;
import com.smartgwt.client.widgets.Canvas;
import com.smartgwt.client.widgets.IButton;
import com.smartgwt.client.widgets.events.ClickEvent;
import com.smartgwt.client.widgets.events.ClickHandler;
import com.smartgwt.client.widgets.grid.ListGrid;
import com.smartgwt.client.widgets.layout.VLayout;
import com.smartgwt.sample.showcase.client.PanelFactory;
import com.smartgwt.sample.showcase.client.ShowcasePanel;
import com.smartgwt.sample.showcase.client.SourceEntity;

public class JPASample extends ShowcasePanel {

    private static final String DESCRIPTION = "For pre-existing JPA entities, Smart GWT can automatically derive fully functional " +
            "DataSources given just the Java classname of the mapped JPA entity.  The grid below is connected " +
            "to a JPA-managed entity via the simple declarations in \"supplyItemJPAAutoDerive.ds.xml\". No other " +
            "configuration or Java code is required beyond the entity itself with the JPA mapping (which is " +
            "a set of samples intended to represent a pre-existing JPA entity).<p/>" +
            "To search, use the controls above the grid's header. Note that data paging is automatically " +
            "enabled. Simply scroll down to load data on demand. Click on the red icon next to each record to " +
            "delete it. Click on a record to edit it and click \"Add New\" to add a new record.  Note that the " +
            "editing controls are type sensitive: a date picker appears for the \"Next Shipment\" field, and " +
            "the \"Units\" field shows a picklist, because its Java type is an Enum.<p/>" +
            "DMI can be used to add business logic that takes place before and after JPA operations to " +
            "enforce security or add additional data validation rules.<p/>";

    public static class Factory implements PanelFactory {

        private String id;

        public ShowcasePanel create() {
            JPASample panel = new JPASample();
            id = panel.getID();
            return panel;
        }

        public String getID() {
            return id;
        }

        public String getDescription() {
            return DESCRIPTION;
        }
    }

    protected boolean isTopIntro() {
        return true;
    }

    public Canvas getViewPanel() {
        final ListGrid listGrid = new ListGrid();
        listGrid.setWidth(900);
        listGrid.setHeight(224);
        listGrid.setAlternateRecordStyles(true);
        listGrid.setDataSource(DataSource.get("supplyItemJPAAutoDerive"));
        listGrid.setAutoFetchData(true);
        listGrid.setShowFilterEditor(true);
        listGrid.setDataPageSize(50);
        listGrid.setCanEdit(true);
        listGrid.setEditEvent(ListGridEditEvent.CLICK);
        listGrid.setCanRemoveRecords(true);

        IButton newButton = new IButton("Add New");
        newButton.addClickHandler(new ClickHandler() {
            public void onClick(ClickEvent event) {
                listGrid.startEditingNew();
            }
        });


        VLayout layout = new VLayout(15);
        layout.addMember(listGrid);
        layout.addMember(newButton);

        return layout;
    }

    public String getIntro() {
        return DESCRIPTION;
    }

    public SourceEntity[] getSourceUrls() {
        return new SourceEntity[]{
                new SourceEntity("SupplyItemHB.java", JAVA, "source/beans/SupplyItemHB.java.html", true),
                new SourceEntity("META-INF/persistence.xml", XML, "source/ds/common/persistence1.xml.html", true)
            };
    }
}

==> smartgwtee-eval-12.0p.zip: smartgwtee-12.0p/samples/showcase/src/com/smartgwt/sample/showcase/client/dataintegration/java/jpa/JPASample.java <==
/*
 * Isomorphic SmartGWT web presentation layer
 * Copyright 2000 and beyond Isomorphic Software, Inc.
 *
 * OWNERSHIP NOTICE
 * Isomorphic Software owns and reserves all rights not expressly granted in this source code,
 * including all intellectual property rights to the structure, sequence, and format of this code
 * and to all designs, interfaces, algorithms, schema, protocols, and inventions expressed herein.
 *
 *  If you have any questions, please email <sourcecode@isomorphic.com>.
 *
 *  This entire comment must accompany any portion of Isomorphic Software source code that is
 *  copied or moved from this file.
 */
package com.smartgwt.sample.showcase.client.dataintegration.java.jpa;

import com.smartgwt.client.data.DataSource;
import com.smartgwt.client.types.ListGridEditEvent;
import com.smartgwt.client.widgets.Canvas;
import com.smartgwt.client.widgets.IButton;
import com.smartgwt.client.widgets.events.ClickEvent;
import com.smartgwt.client.widgets.events.ClickHandler;
import com.smartgwt.client.widgets.grid.ListGrid;
import com.smartgwt.client.widgets.layout.VLayout;
import com.smartgwt.sample.showcase.client.PanelFactory;
import com.smartgwt.sample.showcase.client.ShowcasePanel;
import com.smartgwt.sample.showcase.client.SourceEntity;

public class JPASample extends ShowcasePanel {

    private static final String DESCRIPTION = "For pre-existing JPA entities, Smart GWT can automatically derive fully functional " +
            "DataSources given just the Java classname of the mapped JPA entity.  The grid below is connected " +
            "to a JPA-managed entity via the simple declarations in \"supplyItemJPAAutoDerive.ds.xml\". No other " +
            "configuration or Java code is required beyond the entity itself with the JPA mapping (which is " +
            "a set of samples intended to represent a pre-existing JPA entity).<p/>" +
            "To search, use the controls above the grid's header. Note that data paging is automatically " +
            "enabled. Simply scroll down to load data on demand. Click on the red icon next to each record to " +
            "delete it. Click on a record to edit it and click \"Add New\" to add a new record.  Note that the " +
            "editing controls are type sensitive: a date picker appears for the \"Next Shipment\" field, and " +
            "the \"Units\" field shows a picklist, because its Java type is an Enum.<p/>" +
            "DMI (Direct Method Invocation) can be used to add business logic that takes place before and after JPA operations to " +
            "enforce security or add additional data validation rules.<p/>";

    public static class Factory implements PanelFactory {

        private String id;

        public ShowcasePanel create() {
            JPASample panel = new JPASample();
            id = panel.getID();
            return panel;
        }

        public String getID() {
            return id;
        }

        public String getDescription() {
            return DESCRIPTION;
        }
    }

    protected boolean isTopIntro() {
        return true;
    }

    public Canvas getViewPanel() {
        final ListGrid listGrid = new ListGrid();
        listGrid.setWidth(900);
        listGrid.setHeight(224);
        listGrid.setAlternateRecordStyles(true);
        listGrid.setDataSource(DataSource.get("supplyItemJPAAutoDerive"));
        listGrid.setAutoFetchData(true);
        listGrid.setShowFilterEditor(true);
        listGrid.setDataPageSize(50);
        listGrid.setCanEdit(true);
        listGrid.setEditEvent(ListGridEditEvent.CLICK);
        listGrid.setCanRemoveRecords(true);

        IButton newButton = new IButton("Add New");
        newButton.addClickHandler(new ClickHandler() {
            public void onClick(ClickEvent event) {
                listGrid.startEditingNew();
            }
        });


        VLayout layout = new VLayout(15);
        layout.addMember(listGrid);
        layout.addMember(newButton);

        return layout;
    }

    public String getIntro() {
        return DESCRIPTION;
    }

    public SourceEntity[] getSourceUrls() {
        return new SourceEntity[]{
                new SourceEntity("SupplyItemHB.java", JAVA, "source/beans/SupplyItemHB.java.html", true),
                new SourceEntity("META-INF/persistence.xml", XML, "source/ds/common/persistence1.xml.html", true)
            };
    }
}
